@@ -2,9 +2,9 @@
 #' @include dplyr_integration.R
 NULL
 
-#' Athena Connection Methods
+#' @title Athena Connection Methods
 #'
-#' Implementations of pure virtual functions defined in the `DBI` package
+#' @description Implementations of pure virtual functions defined in the `DBI` package
 #' for AthenaConnection objects.
 #' @slot ptr a list of connecting objects from the SDK paws package.
 #' @slot info a list of metadata objects
@@ -12,6 +12,7 @@ NULL
 #' @name AthenaConnection
 #' @keywords internal
 #' @inheritParams methods::show
+#' @importFrom utils modifyList
 NULL
 
 class_cache <- new.env(parent = emptyenv())
@@ -29,7 +30,9 @@ AthenaConnection <- function(aws_access_key_id = NULL,
                              profile_name = NULL, 
                              aws_expiration = NULL,
                              keyboard_interrupt = NULL,
+                             endpoint_override = NULL,
                              ...){
+  kwargs = list(...)
   # get lower level paws methods
   get_region <- pkg_method("get_region", "paws.common")
   get_profile_name <- pkg_method("get_profile_name", "paws.common")
@@ -41,35 +44,56 @@ AthenaConnection <- function(aws_access_key_id = NULL,
   prof_name <- if(!(is.null(aws_access_key_id) || is.null(aws_secret_access_key) || is.null(aws_session_token))) NULL else get_profile_name(profile_name)
   
   # format credentials to pass to paws sdk
-  Config <- cred_set(aws_access_key_id, aws_secret_access_key, aws_session_token, prof_name, RegionName)
+  Config <- cred_set(
+    aws_access_key_id,
+    aws_secret_access_key,
+    aws_session_token,
+    prof_name,
+    RegionName
+  )
+  if(!is.null(kwargs$endpoint))
+    stop(
+      "Please use `endpoint_override` to override AWS service endpoints.",
+      call. = F
+    )
+  # set up any endpoint url for each aws service: athena, s3, glue
+  endpoints = set_endpoints(endpoint_override)
   
-  tryCatch({Athena <- paws::athena(config = Config)
-            S3 <- paws::s3(config = Config)
-            glue <- paws::glue(config = Config)})
+  tryCatch({
+    Athena <- paws::athena(config = modifyList(Config, c(kwargs , list(endpoint = endpoints$athena))))
+    S3 <- paws::s3(config = modifyList(Config, c(kwargs , list(endpoint = endpoints$s3))))
+    glue <- paws::glue(config = modifyList(Config, c(kwargs , list(endpoint = endpoints$glue))))
+  })
   
   if(is.null(s3_staging_dir) && !is.null(work_group)){
-    tryCatch(s3_staging_dir <- Athena$get_work_group(WorkGroup = work_group)$WorkGroup$Configuration$ResultConfiguration$OutputLocation)
+    tryCatch(
+      s3_staging_dir <- Athena$get_work_group(WorkGroup = work_group)$WorkGroup$Configuration$ResultConfiguration$OutputLocation
+    )
   }
-  
   # return a subset of api function to reduce object size
-  ptr_ll <- list(Athena = Athena[c(".internal","start_query_execution", "get_query_execution","stop_query_execution", "get_query_results",
-                               "get_work_group","list_work_groups","update_work_group","create_work_group","delete_work_group")],
-              S3 = S3[c(".internal", "put_object", "get_object","delete_object","delete_objects","list_objects_v2")],
-              glue = glue[c(".internal", "get_databases","get_tables","get_table","delete_table")])
-  
+  ptr_ll <- list(
+    Athena = Athena[c(".internal","start_query_execution", "get_query_execution","stop_query_execution", "get_query_results",
+        "get_work_group","list_work_groups","update_work_group","create_work_group","delete_work_group")],
+    S3 = S3[c(".internal", "put_object", "get_object","delete_object","delete_objects","list_objects_v2")],
+    glue = glue[c(".internal", "get_databases","get_tables","get_table","delete_table")]
+  )
   s3_staging_dir <- s3_staging_dir %||% get_aws_env("AWS_ATHENA_S3_STAGING_DIR")
   
-  if(is.null(s3_staging_dir)) {stop("Please set `s3_staging_dir` either in parameter `s3_staging_dir`, environmental varaible `AWS_ATHENA_S3_STAGING_DIR`",
-                                    "or when work_group is defined in `create_work_group()`", call. = F)}
-  
-  info <- list(profile_name = prof_name, s3_staging = s3_staging_dir,
-               dbms.name = schema_name, work_group = work_group %||% "primary",
-               poll_interval = poll_interval, encryption_option = encryption_option,
-               kms_key = kms_key, expiration = aws_expiration,
-               timezone = character(),
-               keyboard_interrupt = keyboard_interrupt,
-               region_name = RegionName)
-  
+  if(is.null(s3_staging_dir))
+    stop(
+      "Please set `s3_staging_dir` either in parameter `s3_staging_dir`, environmental varaible `AWS_ATHENA_S3_STAGING_DIR`",
+      "or when work_group is defined in `create_work_group()`", call. = F
+    )
+  info <- list(
+    profile_name = prof_name, s3_staging = s3_staging_dir,
+    dbms.name = schema_name, work_group = work_group %||% "primary",
+    poll_interval = poll_interval, encryption_option = encryption_option,
+    kms_key = kms_key, expiration = aws_expiration,
+    timezone = character(),
+    keyboard_interrupt = keyboard_interrupt,
+    region_name = RegionName,
+    endpoint_override = endpoints
+  )
   res <- new(
     "AthenaConnection",
     ptr = list2env(ptr_ll, parent = emptyenv()),
@@ -696,7 +720,9 @@ setMethod(
 #' Send query, retrieve results and then clear result set
 #'
 #' @note If the user does not have permission to remove AWS S3 resource from AWS Athena output location, then an AWS warning will be returned.
-#'       It is better use query caching \code{\link{noctua_options}} so that the warning doesn't repeatedly show.
+#'       For example \code{AccessDenied (HTTP 403). Access Denied}.
+#'       It is better use query caching or optionally prevent clear AWS S3 resource using \code{\link{noctua_options}}
+#'       so that the warning doesn't repeatedly show.
 #' @name dbGetQuery
 #' @inheritParams DBI::dbGetQuery
 #' @param statistics If set to \code{TRUE} will print out AWS Athena statistics of query.
